@@ -131,7 +131,6 @@ list__process_line (char     *line,
 		
 		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 		fdata->path = remove_level_from_path (fdata->full_path);
-		fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 
 	} else if (arj_comm->line_no == 2) { /* Read file size and date. */
 		FileData  *fdata;
@@ -159,7 +158,8 @@ list__process_line (char     *line,
 
 
 static void
-fr_command_arj_list (FRCommand *comm)
+fr_command_arj_list (FRCommand  *comm,
+		     const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
 				      list__process_line,
@@ -188,7 +188,7 @@ fr_command_arj_add (FRCommand     *comm,
 	fr_process_begin_command (comm->process, "arj");
 
 	fr_process_add_arg (comm->process, "a");
-
+	
 	if (base_dir != NULL) 
 		fr_process_set_working_dir (comm->process, base_dir);
 
@@ -355,9 +355,9 @@ fr_command_arj_init (FRCommand *comm)
 {
 	comm->file_type = FR_FILE_TYPE_ARJ;
 
-	comm->propCanModify                = TRUE;
 	comm->propAddCanUpdate             = TRUE; 
-	comm->propAddCanReplace            = TRUE; 
+	comm->propAddCanReplace            = TRUE;
+	comm->propAddCanStoreFolders       = FALSE;
 	comm->propExtractCanAvoidOverwrite = TRUE;
 	comm->propExtractCanSkipOlder      = TRUE;
 	comm->propExtractCanJunkPaths      = TRUE;
